@@ -405,6 +405,7 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_ibinfoico').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_ibinfoico2').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_iblabels').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_html5warning').style.visibility = 'collapse';
 	}
 
 	if (this.appversion < 47) {
@@ -412,7 +413,10 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_hideeditbm').style.visibility = 'collapse';
 	}
 	
-
+	if (this.appversion < 48) {
+	  document.getElementById('ctraddon_pw_altautocompl').style.visibility = 'collapse';
+	}
+	
 	function PrefListener(branch_name, callback) {
 	  // Keeping a reference to the observed preference branch or it will get
 	  // garbage collected.
