@@ -60,6 +60,7 @@ pref("extensions.classicthemerestorer.ctroldsearch",false);
 pref("extensions.classicthemerestorer.ctroldsearchc",false);
 pref("extensions.classicthemerestorer.osearch_meoit",false);
 pref("extensions.classicthemerestorer.osearch_dm",false);
+pref("extensions.classicthemerestorer.osearch_iwidth",true);
 pref("extensions.classicthemerestorer.addonversion",true);
 pref("extensions.classicthemerestorer.alt_addonsm",false);
 pref("extensions.classicthemerestorer.am_nowarning",false);
@@ -116,6 +117,7 @@ pref("extensions.classicthemerestorer.hideprbutton",false);
 pref("extensions.classicthemerestorer.urlbardropm",false);
 pref("extensions.classicthemerestorer.urlbardropm2",false);
 pref("extensions.classicthemerestorer.altreaderico",false);
+pref("extensions.classicthemerestorer.altautocompl",false);
 
 pref("extensions.classicthemerestorer.ib_nohovcolor",false);
 pref("extensions.classicthemerestorer.ib_graycolor",false);
@@ -192,6 +194,7 @@ pref("extensions.classicthemerestorer.tabthrobber","throbber_default");
 pref("extensions.classicthemerestorer.bmanimation",true);
 pref("extensions.classicthemerestorer.pananimation",true);
 pref("extensions.classicthemerestorer.fsaduration",true);
+pref("extensions.classicthemerestorer.html5warning",true);
 
 // CTR area
 pref("extensions.classicthemerestorer.toolsitem",true);
@@ -276,4 +279,7 @@ pref("extensions.classicthemerestorer.aboutprefsww",850);
 pref("extensions.classicthemerestorer.aboutprefswh",670);
 
 // first run/reset preference
-pref("extensions.classicthemerestorer.ctrreset",true);
\ No newline at end of file
+pref("extensions.classicthemerestorer.ctrreset",true);
+
+// other
+pref("extensions.classicthemerestorer.cstatextlb",false);
\ No newline at end of file
